import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Properties;

import javax.jms.QueueConnectionFactory;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

public class Requestor
{
	private static final String DEFAULT_BROKER_NAME = "jnp://127.0.0.1:1099";
	private static final String DEFAULT_USER_NAME = "guest";
	private static final String DEFAULT_PASSWORD = "guest";
	private static final String DEFAULT_QUEUE = "testResponse";

	private javax.jms.QueueConnection connect = null;
	private javax.jms.QueueSession session = null;
	private javax.jms.QueueRequestor requestor = null;

	/** Create JMS client for sending messages. */
	private void start ( String broker, String username, String password, String sQueue)
	{
		// Create a connection.
		try
		{
			Properties props = new Properties();
			props.put(Context.INITIAL_CONTEXT_FACTORY,
			"org.jnp.interfaces.NamingContextFactory");
			props.put(Context.URL_PKG_PREFIXES,
			"org.jboss.naming:org.jnp.interfaces");
			props.put(Context.PROVIDER_URL, broker);
			InitialContext iniCtx = new InitialContext(props);
			QueueConnectionFactory qcf = (QueueConnectionFactory) iniCtx
			.lookup("ConnectionFactory");
			javax.jms.QueueConnectionFactory factory;
			//factory = (new progress.message.jclient.QueueConnectionFactory (broker));
			connect = qcf.createQueueConnection (username, password);
			session = connect.createQueueSession(false,javax.jms.Session.AUTO_ACKNOWLEDGE);
		}
		catch (javax.jms.JMSException jmse)
		{
			System.err.println("error: Cannot connect to Broker - " + broker);
			jmse.printStackTrace();
			System.exit(1);
		}
		catch(NamingException e){
			e.printStackTrace();
		}

		// Create the Queue and QueueRequestor for sending requests.
		javax.jms.Queue queue = null;
		try
		{
			// Now that all setup is complete, start the Connection.
			connect.start();
			System.out.println("connection started...");
			queue = session.createQueue (sQueue);
			System.out.println("squeue=" + sQueue);
			requestor = new javax.jms.QueueRequestor(session, queue);

		}
		catch (javax.jms.JMSException jmse)
		{
			jmse.printStackTrace();
			exit();
		}

		try
		{       
			javax.jms.TextMessage msg = session.createTextMessage();
			String spr = getSPRFromFile("D:\\redltvxml\\test\\CPE\\HTTPS_DELETE.xml");
			// TemporaryQueue 
			msg.setText(spr);
			javax.jms.TemporaryQueue tq = session.createTemporaryQueue();
			msg.setJMSReplyTo(tq);
			// msg.setJMSReplyTo(new Destination() {		})
			System.out.println("message has been sent to queue called test");			
			javax.jms.TextMessage textMessage = (javax.jms.TextMessage) requestor.request(msg);
			System.out.println("response has been received from the test service + " + textMessage);
			// The message should be a TextMessage.  Just report it.
			//javax.jms.TextMessage textMessage = (javax.jms.TextMessage) response;
			System.out.println( "[Reply] " + textMessage.getText() );              		

		}
		catch ( java.io.IOException ioe )
		{
			ioe.printStackTrace();
		}
		catch ( javax.jms.JMSException jmse )
		{
			jmse.printStackTrace();
		}
	}
	private static String getSPRFromFile(String fileName) throws IOException
	{
		System.out.println("\nAbsolute file path:"
				+ (new File(fileName).getAbsolutePath()));
		BufferedReader br = new BufferedReader(new FileReader(fileName));
		StringBuffer sprXML = new StringBuffer();
		for (String line; ((line = br.readLine()) != null);)
			sprXML.append(line);
		String strSprXML = sprXML.toString().replaceAll("\\s{2,}", "");
		//System.out.println("\n>>Sending request SPR XML to SAG\n\n" + strSprXML);
		return sprXML.toString();
	}
	/** Cleanup resources cleanly and exit. */
	private void exit()
	{
		try
		{
			requestor.close();
			connect.close();
		}
		catch (javax.jms.JMSException jmse)
		{
			jmse.printStackTrace();
		}

		System.exit(0);
	}

	//
	// NOTE: the remainder of this sample deals with reading arguments
	// and does not utilize any JMS classes or code.
	//

	/** Main program entry point. */
	public static void main(String argv[]) {

		// Values to be read from parameters
		String broker    = DEFAULT_BROKER_NAME;
		String username  = DEFAULT_USER_NAME;
		String password  = DEFAULT_PASSWORD;
		String queue     = DEFAULT_QUEUE;       

		// Start the JMS client for sending requests.
		Requestor requestor = new Requestor();
		requestor.start (broker, username, password, queue);

	}

}


